/*
 * Copyright (c) 田梓萱[小草林] 2021-2024.
 * All Rights Reserved.
 * All codes are protected by China's regulations on the protection of computer software, and infringement must be investigated.
 * 版权所有 (c) 田梓萱[小草林] 2021-2024.
 * 所有代码均受中国《计算机软件保护条例》保护，侵权必究.
 */
package ink.xcl.leventbus

import ink.xcl.leventbus.core.Config
import ink.xcl.leventbus.core.LiveEvent
import ink.xcl.leventbus.core.LiveEventBusCore
import ink.xcl.leventbus.core.Observable
import ink.xcl.leventbus.core.ObservableConfig

object LiveEventBus {
    /**
     * get observable by key with type
     *
     * @param key String
     * @param type Class
     * @param <T> T
     * @return Observable </T>
     */
    operator fun <T> get(key: String, type: Class<T>): Observable<T> {
        return LiveEventBusCore.get().with(key, type)
    }

    /**
     * get observable by key
     *
     * @param key String
     * @param <T> T
     * @return Observable </T>
     */
    operator fun <T> get(key: String): Observable<T> {
        return get(key, Any::class.java) as Observable<T>
    }

    /**
     * get observable from eventType
     *
     * @param eventType Class
     * @param <T> T
     * @return Observable </T>
     */
    operator fun <T : LiveEvent?> get(eventType: Class<T>): Observable<T> {
        return get(eventType.name, eventType)
    }

    /**
     * use the inner class Config to set params first of all, call config to get the Config instance
     * then, call the method of Config to config LiveEventBus call this method in
     * Application.onCreate
     *
     * @return Config
     */
    fun config(): Config {
        return LiveEventBusCore.get().config()
    }

    /**
     * use the inner class Config to set params first of all, call config to get the Config instance
     * then, call the method of Config to config LiveEventBus call this method in
     * Application.onCreate
     *
     * @param key String
     * @return ObservableConfig
     */
    fun config(key: String): ObservableConfig? {
        return LiveEventBusCore.get().config(key)
    }
}
