/*
 * Copyright (c) 田梓萱[小草林] 2021-2024.
 * All Rights Reserved.
 * All codes are protected by China's regulations on the protection of computer software, and infringement must be investigated.
 * 版权所有 (c) 田梓萱[小草林] 2021-2024.
 * 所有代码均受中国《计算机软件保护条例》保护，侵权必究.
 */
package ink.xcl.leventbus.core

import android.content.Context
import ink.xcl.leventbus.logger.Logger
import ink.xcl.leventbus.utils.AppUtils.Companion.init

class Config {
    /**
     * lifecycleObserverAlwaysActive set if then observer can always receive message true: observer
     * can always receive message false: observer can only receive message when resumed
     *
     * @param active boolean
     * @return Config
     */
    fun lifecycleObserverAlwaysActive(active: Boolean): Config {
        LiveEventBusCore.get().setLifecycleObserverAlwaysActive(active)
        return this
    }

    /**
     * @param clear boolean
     * @return true: clear livedata when no observer observe it false: not clear livedata unless app
     *   was killed
     */
    fun autoClear(clear: Boolean): Config {
        LiveEventBusCore.get().setAutoClear(clear)
        return this
    }

    /**
     * config broadcast only if you called this method, you can use broadcastValue() to send
     * broadcast message
     *
     * @param context Context
     * @return Config
     */
    fun setContext(context: Context?): Config {
        init(context)
        LiveEventBusCore.get().registerReceiver()
        return this
    }

    /**
     * setLogger, if not set, use DefaultLogger
     *
     * @param logger Logger
     * @return Config
     */
    fun setLogger(logger: Logger): Config {
        LiveEventBusCore.get().setLogger(logger)
        return this
    }

    /**
     * set logger enable or disable, default enable
     *
     * @param enable boolean
     * @return Config
     */
    fun enableLogger(enable: Boolean): Config {
        LiveEventBusCore.get().enableLogger(enable)
        return this
    }
}
